@@ -42,7 +42,7 @@ function delete_redis_key () {
   shift $((OPTIND-1))
 
   while
-  mapfile -t matches < <(${CLI_BIN} -c -p ${port} SCAN $cursor MATCH "*${pattern}")
+  mapfile -t matches < <(${CLI_BIN} -c -p ${port} SCAN $cursor MATCH "${pattern}")
   cursor=${matches[0]}
   [[ "${cursor}" -ne "0" ]]
   do
@@ -153,13 +153,22 @@ then
   LOG "Doing upgrade from 6.1.1"
   ${SCRIPTS_DIR}/update-hostname.sh -d $PERSISTENT_DIRECTORY
   ${SCRIPTS_DIR}/update-network-interfaces.sh -d $PERSISTENT_DIRECTORY
-elif [[ "$RUNNING_RELEASE_VERSION" =~ "7." ]] || [[ "$RUNNING_RELEASE_VERSION" =~ "8." ]] || [[ "$RUNNING_RELEASE_VERSION" =~ ^9[0-9]{2,}.[0-9]{2,}.[0-9]+ ]]
+# Note! Not all upgrade scripts below should be executed when upgrading FROM release 10 and forward. For example "upgrade_dcpr_cloop_wss_ports.sh" MUST NOT be run when upgrading from release 10.
+elif [[ "$RUNNING_RELEASE_VERSION" =~ "7." ]] || [[ "$RUNNING_RELEASE_VERSION" =~ "8." ]] || [[ "$RUNNING_RELEASE_VERSION" =~ "9." ]] || [[ "$RUNNING_RELEASE_VERSION" =~ ^9[0-9]{2,}.[0-9]{2,}.[0-9]+ ]]
 then
   LOG "Doing upgrade from $RUNNING_RELEASE_VERSION"
   ${SCRIPTS_DIR}/update-network-interfaces.sh -d $PERSISTENT_DIRECTORY
   REDIS_PORT=30001 START_REDIS=false ${SCRIPTS_DIR}/copy-nw-settings-to-redis.sh
   REDIS_PORT=30001 ${SCRIPTS_DIR}/dcp-upgrades/dcp404-path-upgrade.sh
   ${SCRIPTS_DIR}/upgrade_lldp.sh
+  ${SCRIPTS_DIR}/upgrade_dcpr_cloop_wss_ports.sh
+  ret=$?
+  if [ $ret -ne 0 ]; then
+    LOG "Script failed: upgrade_dcpr_cloop_wss_ports.sh, code: $ret"
+    exit 1
+  fi
+
+  ${SCRIPTS_DIR}/upgrade_dcp2_automation_mode.sh
 else
   ${SCRIPTS_DIR}/update-network-interfaces.sh -d $PERSISTENT_DIRECTORY
   LOG "Do not know upgrade path"
@@ -167,6 +176,7 @@ fi
 
  REDIS_PORT=30001 ${SCRIPTS_DIR}/remove-password-in-redis.sh
  ${SCRIPTS_DIR}/update-tacacs-radius.sh -d $PERSISTENT_DIRECTORY
+ ${SCRIPTS_DIR}/update-syslog-ng-config.sh -d $PERSISTENT_DIRECTORY
 
 # Check if smartmanager is available or not
 [[ -f /usr/sbin/smartmanager/smartmanager.js ]] && MIGRATE_TO_REDIS=1
@@ -178,6 +188,8 @@ if [[ ${MIGRATE_TO_REDIS} -ne 0 ]]; then
     LOG "Script failed: migrate-to-redis.sh, code: $ret"
     exit 1
   fi
+else
+   REDIS_PORT=30001 ${SCRIPTS_DIR}/handle-shadow-user-accounts.sh
 fi
 
 exit 0
